@@ -81,10 +81,12 @@ xnt_common_opts.update({
                                            straxen.PeaksHighEnergy,
                                            straxen.PeakletsHighEnergy,
                                            straxen.PeakletClassificationHighEnergy,
+                                           straxen.BayesPeakClassification,
                                            straxen.MergedS2sHighEnergy,
                                            straxen.EventInfo,
                                            straxen.PeakShadow,
                                            straxen.EventShadow,
+                                           straxen.EventwBayesClass,
                                            straxen.PeakAmbience,
                                            straxen.EventAmbience,
                                            ],
@@ -107,8 +109,11 @@ xnt_common_opts.update({
 ##
 
 
-def xenonnt(cmt_version='global_ONLINE', **kwargs):
+def xenonnt(cmt_version='global_ONLINE', _from_cutax=False,  **kwargs):
     """XENONnT context"""
+    if not _from_cutax and cmt_version != 'global_ONLINE':
+        warnings.warn('Don\'t load a context directly from straxen, '
+                      'use cutax instead!')
     st = straxen.contexts.xenonnt_online(**kwargs)
     st.apply_cmt_version(cmt_version)
     return st
@@ -518,6 +523,7 @@ x1t_common_config = dict(
     peak_right_extension=30,
     s1_max_rise_time_post100=150,
     s1_min_coincidence=3,
+    event_s1_min_coincidence=3,
     # Events*
     left_event_extension=int(0.3e6),
     right_event_extension=int(1e6),
