@@ -15,15 +15,18 @@ export, __all__ = strax.exporter()
 corrections_w_file = ['mlp_model', 'cnn_model', 'gcn_model',
                       's2_xy_map_mlp', 's2_xy_map_cnn', 's2_xy_map_gcn', 's2_xy_map',
                       's1_xyz_map_mlp', 's1_xyz_map_cnn', 's1_xyz_map_gcn',
-                      'fdc_map_mlp', 'fdc_map_cnn', 'fdc_map_gcn', 's1_aft_xyz_map']
+                      'fdc_map_mlp', 'fdc_map_cnn', 'fdc_map_gcn', 's1_aft_xyz_map',
+                      'bayes_model']
 
 single_value_corrections = ['elife_xenon1t', 'elife', 'baseline_samples_nv',
                             'electron_drift_velocity', 'electron_drift_time_gate',
-                            'se_gain', 'rel_extraction_eff', 'relative_light_yield']
+                            'relative_light_yield', 'electron_diffusion_cte']
 
 arrays_corrections = ['hit_thresholds_tpc', 'hit_thresholds_he',
                       'hit_thresholds_nv', 'hit_thresholds_mv']
 
+dict_corrections = ['se_gain', 'rel_extraction_eff', 'avg_se_gain']
+
 # needed because we pass these names as strax options which then get paired with the default reconstruction algorithm
 # important for apply_cmt_version
 posrec_corrections_basenames = ['s1_xyz_map', 'fdc_map', 's2_xy_map']
@@ -99,7 +102,7 @@ class CorrectionsManagementServices():
 
         if 'to_pe_model' in model_type:
             return self.get_pmt_gains(run_id, model_type, version)
-        elif model_type in single_value_corrections or model_type in arrays_corrections:
+        elif model_type in single_value_corrections or model_type in arrays_corrections or model_type in dict_corrections:
             return self._get_correction(run_id, model_type, version)
         elif model_type in corrections_w_file:
             return self.get_config_from_cmt(run_id, model_type, version)
@@ -149,7 +152,7 @@ class CorrectionsManagementServices():
                     raise CMTnanValueError(f"For {correction} there are NaN values, this means no correction available "
                                            f"for {run_id} in version {version}, please check e-logbook for more info ")
  
-                if correction in corrections_w_file or correction in arrays_corrections or version in 'ONLINE':
+                if correction in corrections_w_file or correction in arrays_corrections or version in 'ONLINE' or correction in dict_corrections:
                     df = self.interface.interpolate(df, when, how='fill')
                 else:
                     df = self.interface.interpolate(df, when)
