@@ -1,5 +1,8 @@
 import strax
 from straxen import pre_apply_function
+
+import numpy as np
+
 export, __all__ = strax.exporter()
 
 
@@ -7,7 +10,7 @@ export, __all__ = strax.exporter()
 @strax.takes_config(
     strax.Option(
         name='event_info_function',
-        default='pre_apply_function',
+        default='pre_apply_function', infer_type=False,
         help="Function that must be applied to all event_info data. Do not change.",
     )
 )
@@ -16,8 +19,7 @@ class EventInfo(strax.MergeOnlyPlugin):
     Plugin which merges the information of all event data_kinds into a
     single data_type.
     """
-    depends_on = ['events',
-                  'event_basics',
+    depends_on = ['event_basics',
                   'event_positions',
                   'corrected_areas',
                   'energy_estimates',
@@ -25,7 +27,7 @@ class EventInfo(strax.MergeOnlyPlugin):
                   ]
     save_when = strax.SaveWhen.ALWAYS
     provides = 'event_info'
-    __version__ = '0.0.1'
+    __version__ = '0.0.2'
 
     def compute(self, **kwargs):
         event_info_function = self.config['event_info_function']
@@ -47,11 +49,11 @@ class EventInfo1T(strax.MergeOnlyPlugin):
 
     This only uses 1T data-types as several event-plugins are nT only
     """
-    depends_on = ['events',
-                  'event_basics',
+    depends_on = ['event_basics',
                   'event_positions',
                   'corrected_areas',
-                  'energy_estimates']
+                  'energy_estimates',
+                  ]
     provides = 'event_info'
     save_when = strax.SaveWhen.ALWAYS
-    __version__ = '0.0.0'
+    __version__ = '0.0.1'
