@@ -1,14 +1,13 @@
-from re import X
 import strax
 import numpy as np
 import numba
 import straxen
 from .position_reconstruction import DEFAULT_POSREC_ALGO
-from straxen.common import pax_file, get_resource, first_sr1_run
-from straxen.get_corrections import get_correction_from_cmt, get_cmt_resource, is_cmt_option
+from straxen.common import pax_file, get_resource, first_sr1_run, rotate_perp_wires
+from straxen.get_corrections import get_cmt_resource, is_cmt_option
 from straxen.itp_map import InterpolatingMap
-export, __all__ = strax.exporter()
 
+export, __all__ = strax.exporter()
 
 @export
 @strax.takes_config(
@@ -36,6 +35,12 @@ export, __all__ = strax.exporter()
                  default=True, type=bool,
                  help='If true exclude S1s as triggering peaks.',
                  ),
+    strax.Option(name='event_s1_min_coincidence',
+                 default=2, infer_type=False,
+                 help="Event level S1 min coincidence. Should be >= "
+                      "s1_min_coincidence in the peaklet classification"),
+    strax.Option(name='s1_min_coincidence', default=2, type=int,
+                 help="Minimum tight coincidence necessary to make an S1"),
 )
 class Events(strax.OverlapWindowPlugin):
     """
@@ -56,7 +61,7 @@ class Events(strax.OverlapWindowPlugin):
     depends_on = ['peak_basics', 'peak_proximity']
     provides = 'events'
     data_kind = 'events'
-    __version__ = '0.1.0'
+    __version__ = '0.1.1'
     save_when = strax.SaveWhen.NEVER
 
     electron_drift_velocity = straxen.URLConfig(
@@ -75,6 +80,9 @@ class Events(strax.OverlapWindowPlugin):
     events_seen = 0
 
     def setup(self):
+        if self.config['s1_min_coincidence'] > self.config['event_s1_min_coincidence']:
+            raise ValueError('Peak s1 coincidence requirement should be smaller '
+                             'or equal to event_s1_min_coincidence')
         self.drift_time_max = int(self.config['max_drift_length'] / self.electron_drift_velocity)
         # Left_extension and right_extension should be computed in setup to be
         # reflected in cutax too.
@@ -92,6 +100,11 @@ class Events(strax.OverlapWindowPlugin):
         _is_triggering &= (peaks['n_competing'] <= self.config['trigger_max_competing'])
         if self.config['exclude_s1_as_triggering_peaks']:
             _is_triggering &= peaks['type'] == 2
+        else:
+            is_not_s1 = peaks['type'] != 1
+            has_tc_large_enough = (peaks['tight_coincidence']
+                                   >= self.config['event_s1_min_coincidence'])
+            _is_triggering &= (is_not_s1 | has_tc_large_enough)
 
         triggers = peaks[_is_triggering]
 
@@ -620,7 +633,7 @@ class CorrectedAreas(strax.Plugin):
         cs2_top and cs2_bottom are corrected by the corresponding maps,
         and cs2 is the sum of the two.
     """
-    __version__ = '0.2.1'
+    __version__ = '0.3.0'
 
     depends_on = ['event_basics', 'event_positions']
 
@@ -648,7 +661,7 @@ class CorrectedAreas(strax.Plugin):
     # average SE gain for a given time period. default to the value of this run in ONLINE model
     # thus, by default, there will be no time-dependent correction according to se gain
     avg_se_gain = straxen.URLConfig(
-        default='cmt://se_gain?version=ONLINE&run_id=plugin.run_id',
+        default='cmt://avg_se_gain?version=ONLINE&run_id=plugin.run_id',
         help='Nominal single electron (SE) gain in PE / electron extracted. '
              'Data will be corrected to this value')
 
@@ -668,6 +681,16 @@ class CorrectedAreas(strax.Plugin):
         default='cmt://relative_light_yield?version=ONLINE&run_id=plugin.run_id',
         help='Relative light yield (allows for time dependence)'
     )
+    
+    region_linear = straxen.URLConfig(
+        default=28,
+        help='linear cut (cm) for ab region, check out the note https://xe1t-wiki.lngs.infn.it/doku.php?id=jlong:sr0_2_region_se_correction'
+    )
+    
+    region_circular = straxen.URLConfig(
+        default=60,
+        help='circular cut (cm) for ab region, check out the note https://xe1t-wiki.lngs.infn.it/doku.php?id=jlong:sr0_2_region_se_correction'
+    )
 
     def infer_dtype(self):
         dtype = []
@@ -689,12 +712,21 @@ class CorrectedAreas(strax.Plugin):
                        f'Corrected area of {peak_name} S2 in the bottom PMT array [PE]'),
                       (f'{peak_type}cs2', np.float32, f'Corrected area of {peak_name} S2 [PE]'), ]
         return dtype
+    
+    def ab_region(self, x, y):
+        new_x, new_y = rotate_perp_wires(x, y)
+        cond = new_x < self.region_linear
+        cond &= new_x > -self.region_linear
+        cond &= new_x**2 + new_y**2 < self.region_circular**2
+        return cond
+    
+    def cd_region(self, x, y):
+        return ~self.ab_region(x, y)
 
     def compute(self, events):
-        result = dict(
-            time=events['time'],
-            endtime=strax.endtime(events)
-        )
+        result = np.zeros(len(events), self.dtype)
+        result['time'] = events['time']
+        result['endtime'] = events['endtime']
 
         # S1 corrections depend on the actual corrected event position.
         # We use this also for the alternate S1; for e.g. Kr this is
@@ -715,35 +747,66 @@ class CorrectedAreas(strax.Plugin):
             s2_top_map_name = "map"
             s2_bottom_map_name = "map"
 
+        regions = {'ab': self.ab_region, 'cd': self.cd_region}
+
+        # setup SEG and EE corrections
+        # if they are dicts, we just leave them as is
+        # if they are not, we assume they are floats and
+        # create a dict with the same correction in each region
+        if isinstance(self.se_gain, dict):
+            seg = self.se_gain
+        else:
+            seg = {key: self.se_gain for key in regions}
+
+        if isinstance(self.avg_se_gain, dict):
+            avg_seg = self.avg_se_gain
+        else:
+            avg_seg = {key: self.avg_se_gain for key in regions}
+
+        if isinstance(self.rel_extraction_eff, dict):
+            ee = self.rel_extraction_eff
+        else:
+            ee = {key: self.rel_extraction_eff for key in regions}
+
+        # now can start doing corrections
         for peak_type in ["", "alt_"]:
             # S2(x,y) corrections use the observed S2 positions
             s2_positions = np.vstack([events[f'{peak_type}s2_x'], events[f'{peak_type}s2_y']]).T
-
+            
             # corrected s2 with s2 xy map only, i.e. no elife correction
             # this is for s2-only events which don't have drift time info
-            cs2_top_xycorr = (events[f'{peak_type}s2_area'] * events[f'{peak_type}s2_area_fraction_top'] /
-                                    self.s2_xy_map(s2_positions, map_name=s2_top_map_name))
-            cs2_bottom_xycorr = (events[f'{peak_type}s2_area'] *
-                                       (1 - events[f'{peak_type}s2_area_fraction_top']) /
-                                       self.s2_xy_map(s2_positions, map_name=s2_bottom_map_name))
-
-            # Correct for SEgain and extraction efficiency
-            seg_ee_corr = (self.se_gain / self.avg_se_gain) * self.rel_extraction_eff
-            cs2_top_wo_elifecorr = cs2_top_xycorr / seg_ee_corr
-            cs2_bottom_wo_elifecorr = cs2_bottom_xycorr / seg_ee_corr
-            result[f"{peak_type}cs2_wo_elifecorr"] = cs2_top_wo_elifecorr + cs2_bottom_wo_elifecorr
-
-            # cs2aft doesn't need elife/time corrections as they cancel
-            result[f"{peak_type}cs2_area_fraction_top"] = cs2_top_wo_elifecorr / result[f"{peak_type}cs2_wo_elifecorr"]
-
-
+            
+            cs2_top_xycorr = (events[f'{peak_type}s2_area']
+                              * events[f'{peak_type}s2_area_fraction_top']
+                              / self.s2_xy_map(s2_positions, map_name=s2_top_map_name))
+            cs2_bottom_xycorr = (events[f'{peak_type}s2_area']
+                                 * (1 - events[f'{peak_type}s2_area_fraction_top'])
+                                 / self.s2_xy_map(s2_positions, map_name=s2_bottom_map_name))
+            
             # For electron lifetime corrections to the S2s,
             # use drift time computed using the main S1.
             el_string = peak_type + "s2_interaction_" if peak_type == "alt_" else peak_type
             elife_correction = np.exp(events[f'{el_string}drift_time'] / self.elife)
             result[f"{peak_type}cs2_wo_timecorr"] = (cs2_top_xycorr + cs2_bottom_xycorr) * elife_correction
-            result[f"{peak_type}cs2"] = result[f"{peak_type}cs2_wo_elifecorr"] * elife_correction
-            result[f"{peak_type}cs2_bottom"] = cs2_bottom_wo_elifecorr * elife_correction
+
+            for partition, func in regions.items():
+                # partitioned SE and EE
+                partition_mask = func(events[f'{peak_type}s2_x'], events[f'{peak_type}s2_y'])
+
+                # Correct for SEgain and extraction efficiency
+                seg_ee_corr = seg[partition]/avg_seg[partition]*ee[partition]
+
+                # note that these are already masked!
+                cs2_top_wo_elifecorr = cs2_top_xycorr[partition_mask] / seg_ee_corr
+                cs2_bottom_wo_elifecorr = cs2_bottom_xycorr[partition_mask] / seg_ee_corr
+
+                result[f"{peak_type}cs2_wo_elifecorr"][partition_mask] = cs2_top_wo_elifecorr + cs2_bottom_wo_elifecorr
+
+                # cs2aft doesn't need elife/time corrections as they cancel
+                result[f"{peak_type}cs2_area_fraction_top"][partition_mask] = cs2_top_wo_elifecorr / (cs2_top_wo_elifecorr + cs2_bottom_wo_elifecorr)
+
+                result[f"{peak_type}cs2"][partition_mask] = result[f"{peak_type}cs2_wo_elifecorr"][partition_mask] * elife_correction[partition_mask]
+                result[f"{peak_type}cs2_bottom"][partition_mask] = cs2_bottom_wo_elifecorr * elife_correction[partition_mask]
 
         return result
 
@@ -798,12 +861,11 @@ class EventShadow(strax.Plugin):
     This plugin can calculate shadow for main S1 and main S2 in events.
     It also gives the position information of the previous peaks.
     References:
-        * v0.1.3 reference: xenon:xenonnt:ac:prediction:shadow_ambience
+        * v0.1.4 reference: xenon:xenonnt:ac:prediction:shadow_ambience
     """
-    __version__ = '0.1.3'
+    __version__ = '0.1.4'
     depends_on = ('event_basics', 'peak_basics', 'peak_shadow')
     provides = 'event_shadow'
-    save_when = strax.SaveWhen.EXPLICIT
 
     def infer_dtype(self):
         dtype = []
@@ -859,11 +921,11 @@ class EventShadow(strax.Plugin):
                         type_str = key.split('_')[0]
                         res_i[f'{main_peak}shadow_{key}'] = sp[f'shadow_{key}'][idx]
                         res_i[f'{main_peak}dt_{key}'] = sp[f'dt_{key}'][idx]
-                    if 'time' in key:
-                        res_i[f'{main_peak}nearest_dt_{key}'] = sp[f'nearest_dt_{type_str}'][idx]
-                    if 's2' in key:
-                        res_i[f'{main_peak}x_{key}'] = sp[f'x_{key}'][idx]
-                        res_i[f'{main_peak}y_{key}'] = sp[f'y_{key}'][idx]
+                        if 'time' in key:
+                            res_i[f'{main_peak}nearest_dt_{type_str}'] = sp[f'nearest_dt_{type_str}'][idx]
+                        if 's2' in key:
+                            res_i[f'{main_peak}x_{key}'] = sp[f'x_{key}'][idx]
+                            res_i[f'{main_peak}y_{key}'] = sp[f'y_{key}'][idx]
                     # Record the PDF of HalfCauchy
                     res_i[f'{main_peak}pdf_s2_position_shadow'] = sp['pdf_s2_position_shadow'][idx]
 
@@ -883,7 +945,6 @@ class EventAmbience(strax.Plugin):
     __version__ = '0.0.4'
     depends_on = ('event_basics', 'peak_basics', 'peak_ambience')
     provides = 'event_ambience'
-    save_when = strax.SaveWhen.EXPLICIT
 
     @property
     def origin_dtype(self):
@@ -904,7 +965,6 @@ class EventAmbience(strax.Plugin):
 
         # 1. Initialization, ambience is set to be the lowest possible value
         result = np.zeros(len(events), self.dtype)
-
         # 2. Assign peaks features to main S1, main S2 in the event
         for event_i, (event, sp) in enumerate(zip(events, split_peaks)):
             for idx, main_peak in zip([event['s1_index'], event['s2_index']], ['s1_', 's2_']):
