@@ -105,7 +105,7 @@ HE_PREAMBLE = """High energy channels: attenuated signals of the top PMT-array\n
     *HITFINDER_OPTIONS)
 class PulseProcessing(strax.Plugin):
     """
-    1. Split raw_records into:
+    Split raw_records into:
      - (tpc) records
      - aqmon_records
      - pulse_counts
@@ -134,7 +134,11 @@ class PulseProcessing(strax.Plugin):
 
     provides = ('records', 'veto_regions', 'pulse_counts')
     data_kind = {k: k for k in provides}
-    save_when = strax.SaveWhen.TARGET
+    save_when = immutabledict(
+        records=strax.SaveWhen.TARGET,
+        veto_regions=strax.SaveWhen.TARGET,
+        pulse_counts=strax.SaveWhen.ALWAYS,
+    )
 
     def infer_dtype(self):
         # Get record_length from the plugin making raw_records
@@ -328,7 +332,7 @@ def software_he_veto(records, to_pe, chunk_end,
     veto_res = int(veto_res)
     if veto_res > np.iinfo(np.int16).max:
         raise ValueError("Veto resolution does not fit 16-bit int")
-    veto_length = np.ceil(veto_length / veto_res).astype(np.int) * veto_res
+    veto_length = np.ceil(veto_length / veto_res).astype(np.int64) * veto_res
     veto_n = int(veto_length / veto_res) + 1
 
     # 1. Find large peaks in the data.
